@@ -1,15 +1,19 @@
 # --- BEGIN COPYRIGHT BLOCK ---
-# Copyright (C) 2015 Red Hat, Inc.
+# Copyright (C) 2020 Red Hat, Inc.
 # All rights reserved.
 #
 # License: GPL (version 3 or any later version).
 # See LICENSE for details.
 # --- END COPYRIGHT BLOCK ---
 
+import sys
 import os
 from enum import Enum, IntEnum
 from lib389.properties import *
 
+# current module object
+mod = sys.modules[__name__]
+
 (
     MASTER_TYPE,
     HUB_TYPE,
@@ -81,6 +85,7 @@ DN_SCHEMA = "cn=schema"
 DN_MONITOR = "cn=monitor"
 DN_MONITOR_SNMP = "cn=snmp,cn=monitor"
 DN_MONITOR_LDBM = "cn=monitor,cn=ldbm database,cn=plugins,cn=config"
+DN_MONITOR_DATABASE = "cn=database,cn=monitor,cn=ldbm database,cn=plugins,cn=config"
 DN_PWDSTORAGE_SCHEMES = "cn=Password Storage Schemes,cn=plugins,cn=config"
 
 CMD_PATH_SETUP_DS = "setup-ds.pl"
@@ -145,6 +150,7 @@ DN_IMPORT_TASK = "cn=import,%s" % DN_TASKS
 DN_BACKUP_TASK = "cn=backup,%s" % DN_TASKS
 DN_RESTORE_TASK = "cn=restore,%s" % DN_TASKS
 DN_MBO_TASK = "cn=memberOf task,%s" % DN_TASKS
+DN_EUUID_TASK = "cn=entryuuid task,%s" % DN_TASKS
 DN_TOMB_FIXUP_TASK = "cn=fixup tombstones,%s" % DN_TASKS
 DN_FIXUP_LINKED_ATTIBUTES = "cn=fixup linked attributes,%s" % DN_TASKS
 DN_AUTOMEMBER_REBUILD_TASK = "cn=automember rebuild membership,%s" % DN_TASKS
@@ -286,11 +292,11 @@ number_of_instances = 99
 # Standalone topology
 for i in range(port_start, port_start + number_of_instances):
     N+=1
-    exec("HOST_STANDALONE{0} = {1}".format(N, "LOCALHOST"))
-    exec("PORT_STANDALONE{0} = {1}".format(N, i))
-    exec("SECUREPORT_STANDALONE{0} = {1}".format(N, i + 24700))
-    exec("SERVERID_STANDALONE{0} = {1}".format(N, "\"standalone{0}\"".format(N)))
-    exec("REPLICAID_STANDALONE_{0} = {1}".format(N, 65535))
+    setattr(mod, "HOST_STANDALONE{0}".format(N), "LOCALHOST")
+    setattr(mod, "PORT_STANDALONE{0}".format(N), i)
+    setattr(mod, "SECUREPORT_STANDALONE{0}".format(N), i + 24700)
+    setattr(mod, "SERVERID_STANDALONE{0}".format(N), "standalone{0}".format(N))
+    setattr(mod, "REPLICAID_STANDALONE_{0}".format(N), 65535)
 
 # For compatibility
 HOST_STANDALONE = HOST_STANDALONE1
@@ -303,32 +309,32 @@ N=0
 port_start+=100
 for i in range(port_start, port_start + number_of_instances):
     N+=1
-    exec("HOST_MASTER_{0} = {1}".format(N, "LOCALHOST"))
-    exec("PORT_MASTER_{0} = {1}".format(N, i))
-    exec("SECUREPORT_MASTER_{0} = {1}".format(N, i + 24700))
-    exec("SERVERID_MASTER_{0} = {1}".format(N, "\"master{0}\"".format(N)))
-    exec("REPLICAID_MASTER_{0} = {1}".format(N, N))
+    setattr(mod, "HOST_MASTER_{0}".format(N), "LOCALHOST")
+    setattr(mod, "PORT_MASTER_{0}".format(N), i)
+    setattr(mod, "SECUREPORT_MASTER_{0}".format(N), i + 24700)
+    setattr(mod, "SERVERID_MASTER_{0}".format(N), "master{0}".format(N))
+    setattr(mod, "REPLICAID_MASTER_{0}".format(N), N)
 
 # Replication topology - hubs
 N=0
 port_start+=100
 for i in range(port_start, port_start + number_of_instances):
     N+=1
-    exec("HOST_HUB_{0} = {1}".format(N, "LOCALHOST"))
-    exec("PORT_HUB_{0} = {1}".format(N, i))
-    exec("SECUREPORT_HUB_{0} = {1}".format(N, i + 24700))
-    exec("SERVERID_HUB_{0} = {1}".format(N, "\"hub{0}\"".format(N)))
-    exec("REPLICAID_HUB_{0} = {1}".format(N, 65535))
+    setattr(mod, "HOST_HUB_{0}".format(N), "LOCALHOST")
+    setattr(mod, "PORT_HUB_{0}".format(N), i)
+    setattr(mod, "SECUREPORT_HUB_{0}".format(N), i + 24700)
+    setattr(mod, "SERVERID_HUB_{0}".format(N), "hub{0}".format(N))
+    setattr(mod, "REPLICAID_HUB_{0}".format(N), 65535)
 
 # Replication topology - consumers
 N=0
 port_start+=100
 for i in range(port_start, port_start + number_of_instances):
     N+=1
-    exec("HOST_CONSUMER_{0} = {1}".format(N, "LOCALHOST"))
-    exec("PORT_CONSUMER_{0} = {1}".format(N, i))
-    exec("SECUREPORT_CONSUMER_{0} = {1}".format(N, i + 24700))
-    exec("SERVERID_CONSUMER_{0} = {1}".format(N, "\"consumer{0}\"".format(N)))
+    setattr(mod, "HOST_CONSUMER_{0}".format(N), "LOCALHOST")
+    setattr(mod, "PORT_CONSUMER_{0}".format(N), i)
+    setattr(mod, "SECUREPORT_CONSUMER_{0}".format(N), i + 24700)
+    setattr(mod, "SERVERID_CONSUMER_{0}".format(N), "consumer{0}".format(N))
 
 # Cleanup, we don't need to export that
 del N, port_start, number_of_instances
